@@ -17,8 +17,8 @@ class RTROIObservationsSequence :
             dataset.ReferencedROINumber = number_roi
             dataset.ObservationNumber = number_roi 
 
-            dataset.RTROIInterpretedType = ' '
-            dataset.ROIInterpreter = ' '
+            dataset.RTROIInterpretedType = " "
+            dataset.ROIInterpreter = " "
             
             #if self.results['segmentAttributes'][0][number_roi-1]["SegmentDescription"] != "None" : 
             #    dataset.ROIObservationLabel = self.results['segmentAttributes'][0][number_roi-1]["SegmentDescription"]
